# Citation

If you use QuGrad please cite the accompanying paper:

`````{tabs}
````{tab} APA
```{include} citation_files/paper_citation.txt
```
````

````{tab} BIB
```{literalinclude} citation_files/paper_citation.bib
:language: bibtex
```
````

````{tab} RIS
```{literalinclude} citation_files/paper_citation.ris
:language: text
```
````
`````

Additionally, you can reference this code base specifically with the following citation:

`````{tabs}

````{tab} APA
```{include} citation_files/citation.txt
```
````

````{tab} BIB
```{literalinclude} citation_files/citation.bib
:language: bibtex
```
````

````{tab} RIS
```{literalinclude} citation_files/citation.ris
:language: text
```
````

````{tab} EndNote
```{literalinclude} citation_files/citation.enw
:language: text
```
````

````{tab} CodeMeta
```{literalinclude} citation_files/citation_codemeta.json
:language: json
```
````

````{tab} CFF
```{literalinclude} ../../CITATION.cff
:language: yaml
```
````
`````